==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/fi.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Toimet",
    "An error occurred while loading activities" : "Toimia ladattaessa tapahtui virhe",
    "No activity yet" : "Ei toimia vielä",
    "Load more activities" : "Lataa lisää toimia",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "{name} (invisible)" : "{name} (näkymätön)",
    "{name} (restricted)" : "{name} (rajoitettu)",
    "in {path}" : "polussa {path}",
    "This stream will show events like additions, changes & shares" : "Tähän luetteloon ilmestyy tapahtumakuvauksia, kuten lisäyksiä, muutoksia ja jakamisia",
    "There are no events for this filter" : "Tällä suodattimella ei ole näytettäviä tapahtumia",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "Personal activity feed for %s" : "Käyttäjän %s henkilökohtainen toimintasyöte",
    "Your feed URL is invalid" : "Syöteosoitteesi on virheellinen",
    "Your settings have been updated." : "Asetuksesi on päivitetty.",
    "Settings have been updated." : "Asetukset on päivitetty.",
    "Mail" : "Sähköposti",
    "Stream" : "Luettelo",
    "All activities" : "Kaikkien toimet",
    "By others" : "Muiden",
    "By you" : "Sinun",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "Toimintaa kohteessa %s",
    "_and %n more _::_and %n more _" : ["ja %n lisää","ja %n lisää"],
    "Activity notification" : "Ilmoitus toiminnasta",
    ", " : ", ",
    "%s and %s" : "%s ja %s",
    "Activity" : "Toimet",
    "Activity feed" : "Toiminnan syöte",
    "Configure the default activity settings for new users." : "Määritä toimien oletusasetukset uusille käyttäjille.",
    "List your own actions in the stream" : "Listaa omat toimet luettelossa",
    "Notify about your own actions via email" : "Ilmoita omista toimista sähköpostitse",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send emails:" : "Lähetä sähköpostit:",
    "As soon as possible" : "Niin pian kuin mahdollista",
    "Hourly" : "Tunneittain",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Valitse, mitä toimia haluat vastaanottaa sähköpostitse ja minkä toimien tulisi näkyä toiminnan syötteessä.",
    "Settings" : "Asetukset",
    "Enable RSS feed" : "Käytä RSS-syötettä",
    "No more events to load" : "Ei enempää tapahtumia ladattavaksi",
    "Files" : "Tiedostot",
    "Error loading activities" : "Virhe ladatessa toimia",
    "No activities" : "Ei toimia",
    "You are receiving this email because the following things happened at %s" : "Saat tämän viestin, koska kohteessa %s tapahtui seuraavaa",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ja %n lisää","* ja %n lisää"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/fi.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Toimet",
    "An error occurred while loading activities" : "Toimia ladattaessa tapahtui virhe",
    "No activity yet" : "Ei toimia vielä",
    "Load more activities" : "Lataa lisää toimia",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "{name} (invisible)" : "{name} (näkymätön)",
    "{name} (restricted)" : "{name} (rajoitettu)",
    "in {path}" : "polussa {path}",
    "This stream will show events like additions, changes & shares" : "Tähän luetteloon ilmestyy tapahtumakuvauksia, kuten lisäyksiä, muutoksia ja jakamisia",
    "There are no events for this filter" : "Tällä suodattimella ei ole näytettäviä tapahtumia",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "Open file" : "Avaa tiedosto",
    "Personal activity feed for %s" : "Käyttäjän %s henkilökohtainen toimintasyöte",
    "Your feed URL is invalid" : "Syöteosoitteesi on virheellinen",
    "Your settings have been updated." : "Asetuksesi on päivitetty.",
    "Settings have been updated." : "Asetukset on päivitetty.",
    "Mail" : "Sähköposti",
    "Stream" : "Luettelo",
    "All activities" : "Kaikkien toimet",
    "By others" : "Muiden",
    "By you" : "Sinun",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "Toimintaa kohteessa %s",
    "_and %n more _::_and %n more _" : ["ja %n lisää","ja %n lisää"],
    "Activity notification" : "Ilmoitus toiminnasta",
    ", " : ", ",
    "%s and %s" : "%s ja %s",
    "Activity" : "Toimet",
    "Activity feed" : "Toiminnan syöte",
    "Default settings" : "Oletusasetukset",
    "Configure the default activity settings for new users." : "Määritä toimien oletusasetukset uusille käyttäjille.",
    "List your own actions in the stream" : "Listaa omat toimet luettelossa",
    "Notify about your own actions via email" : "Ilmoita omista toimista sähköpostitse",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send emails:" : "Lähetä sähköpostit:",
    "As soon as possible" : "Niin pian kuin mahdollista",
    "Hourly" : "Tunneittain",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Valitse, mitä toimia haluat vastaanottaa sähköpostitse ja minkä toimien tulisi näkyä toiminnan luettelossa.",
    "Settings" : "Asetukset",
    "Enable RSS feed" : "Käytä RSS-syötettä",
    "RSS feed" : "RSS-syöte",
    "No more events to load" : "Ei enempää tapahtumia ladattavaksi",
    "Files" : "Tiedostot",
    "Error loading activities" : "Virhe ladatessa toimia",
    "No activities" : "Ei toimia",
    "You are receiving this email because the following things happened at %s" : "Saat tämän viestin, koska kohteessa %s tapahtui seuraavaa",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ja %n lisää","* ja %n lisää"]
},
"nplurals=2; plural=(n != 1);");
